[![pipeline status](https://gitlab.com/gerbolyze/gerbonara/badges/master/pipeline.svg)](https://gitlab.com/gerbolyze/gerbonara/commits/master)
[![coverage report](https://gitlab.com/gerbolyze/gerbonara/badges/master/coverage.svg)](https://gitlab.com/gerbolyze/gerbonara/commits/master)
[![pypi](https://img.shields.io/pypi/v/gerbonara)](https://pypi.org/project/gerbonara/)
[![aur](https://img.shields.io/aur/version/python-gerbonara)](https://aur.archlinux.org/packages/python-gerbonara/)

# gerbonara

Tools to handle Gerber and Excellon files in Python.

This repository is a friendly fork of [phsilva's pcb-tools](https://github.com/curtacircuitos/pcb-tools) with
[extensions from opiopan](https://github.com/opiopan/pcb-tools-extension) integrated. We decided to fork pcb-tools since
we need it as a dependency for [gerbolyze](https://gitlab.com/gerbolyze/gerbolyze) and pcb-tools was sometimes very
behind on bug fixes.

# Installation

Arch Linux:

```
yay -S python-gerbonara
```

Python:

```
pipx install gerbonara
```

# Documentation and Examples

Documentation can be found at:

https://gerbolyze.gitlab.io/gerbonara

# Issues

Please file any bugs at our issue tracker:

https://gitlab.com/gerbolyze/gerbonara/-/issues

---

Made with ❤️ and 🐍.
